@@ -1,8 +1,8 @@
 import random
 
 import gym
-import torch
 import numpy
+import torch
 
 
 class TextRLEnv(gym.Env):
@@ -14,7 +14,7 @@ class TextRLEnv(gym.Env):
         self.tokenizer = tokenizer
         self.observation_space = observation_input
         self.target_table = {}
-        self.input_text = ""
+        self.input_item = [""]
         self.predicted = []
 
         self.reset()
@@ -23,27 +23,32 @@ class TextRLEnv(gym.Env):
         if isinstance(action, numpy.ndarray):
             action = numpy.argmax(action)
         predicted, finish, predicted_str = self._predict(vocab_id=action)
-        reward = self.get_reward(self.input_text, predicted, finish)
+        reward = self.get_reward(self.input_item, predicted, finish)
         self.predicted = predicted
         return self._get_obs(predicted), reward, finish, {"predicted_str": predicted_str}
 
-    def get_reward(self, input_text, predicted_list, finish):
+    def get_reward(self, input_item, predicted_list, finish):
         reward = 1
         return reward
 
-    def reset(self, input_text=None):
+    def gat_obs_input(self, input_item):
+        return input_item[0]
+
+    def reset(self, input_item=None):
         self.predicted = []
-        if input_text is None:
-            self.input_text = random.choice(self.observation_space)
+        if input_item is None:
+            self.input_item = random.choice(self.observation_space)
         else:
-            self.input_text = input_text
+            self.input_item = input_item
         return self._get_obs()
 
     def _get_obs(self, predicted=[]):
         with torch.no_grad():
             p_text = self.tokenizer.convert_tokens_to_string(predicted)
             if len([k for k, v in self.model.named_parameters() if 'decoder' in k]) > 0:
-                feature_dict = self.tokenizer([self.input_text], return_tensors='pt', add_special_tokens=False).to(
+                feature_dict = self.tokenizer([self.gat_obs_input(self.input_item)],
+                                              return_tensors='pt',
+                                              add_special_tokens=False).to(
                     self.model.device)
                 predicted = [self.tokenizer.eos_token] + predicted
                 dec_input = torch.tensor([self.tokenizer.convert_tokens_to_ids(predicted)]).to(self.model.device)
@@ -51,7 +56,8 @@ class TextRLEnv(gym.Env):
                 prediction = self.model(**feature_dict, output_hidden_states=True)
                 outputs = prediction.decoder_hidden_states[-1].squeeze(0)
             else:
-                feature_dict = self.tokenizer([[self.input_text, p_text]], return_tensors='pt',
+                feature_dict = self.tokenizer([[self.gat_obs_input(self.input_item), p_text]],
+                                              return_tensors='pt',
                                               add_special_tokens=False).to(self.model.device)
                 prediction = self.model(**feature_dict, output_hidden_states=True)
                 outputs = prediction.hidden_states[-1].squeeze(0)
